@@ -8,4 +8,9 @@
 		)
   invisible()
 	}
-}
\ No newline at end of file
+}
+
+.onAttach <- function(libname, pkgname) {
+  packageStartupMessage(
+    paste("\nThis is santaR version", utils::packageVersion("santaR"), "\n"))
+}
